package TestApp::View::Mason;
use strict;
use warnings;
use base 'CatalystX::Features::View::Mason';

__PACKAGE__->config(use_match => 0);

=head1 NAME

TestApp::View::Mason - Mason View Component for TestApp

=head1 DESCRIPTION

Mason View Component for TestApp

=head1 SEE ALSO

L<TestApp>, L<HTML::Mason>

=head1 AUTHOR

Rodrigo de Oliveira

=head1 LICENSE

This library is free software . You can redistribute it and/or modify it under
the same terms as perl itself.

=cut

1;
